@@ -104,6 +104,7 @@ typedef enum
 	FreeRDP_RdstlsSecurity = 1111,
 	FreeRDP_AadSecurity = 1112,
 	FreeRDP_RemoteCredentialGuard = 1114,
+	FreeRDP_RestrictedAdminModeSupported = 1115,
 	FreeRDP_MstscCookieMode = 1152,
 	FreeRDP_SendPreconnectionPdu = 1156,
 	FreeRDP_SmartcardLogon = 1282,
@@ -154,6 +155,7 @@ typedef enum
 	FreeRDP_GatewayHttpExtAuthSspiNtlm = 2001,
 	FreeRDP_GatewayArmTransport = 2004,
 	FreeRDP_GatewayIgnoreRedirectionPolicy = 2012,
+	FreeRDP_GatewayAvdUseTenantid = 2020,
 	FreeRDP_RemoteApplicationMode = 2112,
 	FreeRDP_DisableRemoteAppCapsCheck = 2121,
 	FreeRDP_RemoteAppLanguageBarSupported = 2124,
@@ -267,7 +269,9 @@ typedef enum
  */
 typedef enum
 {
-    FreeRDP_XPan = 1552,
+    FreeRDP_MonitorLocalShiftX = 395,
+	FreeRDP_MonitorLocalShiftY = 396,
+	FreeRDP_XPan = 1552,
 	FreeRDP_YPan = 1553,
 	FreeRDP_INT32_UNUSED = -1
 } FreeRDP_Settings_Keys_Int32;
@@ -311,8 +315,6 @@ typedef enum
 	FreeRDP_DesktopPosX = 390,
 	FreeRDP_DesktopPosY = 391,
 	FreeRDP_NumMonitorIds = 394,
-	FreeRDP_MonitorLocalShiftX = 395,
-	FreeRDP_MonitorLocalShiftY = 396,
 	FreeRDP_MonitorFlags = 398,
 	FreeRDP_MonitorAttributeFlags = 399,
 	FreeRDP_MultitransportFlags = 512,
@@ -422,7 +424,8 @@ typedef enum
  */
 typedef enum
 {
-    FreeRDP_ParentWindowId = 1543,
+    FreeRDP_MonitorOverrideFlags = 154,
+	FreeRDP_ParentWindowId = 1543,
 	FreeRDP_UINT64_UNUSED = -1
 } FreeRDP_Settings_Keys_UInt64;
 
@@ -511,9 +514,17 @@ typedef enum
 	FreeRDP_GatewayAvdDiagnosticserviceurl = 2009,
 	FreeRDP_GatewayAvdHubdiscoverygeourl = 2010,
 	FreeRDP_GatewayAvdActivityhint = 2011,
+	FreeRDP_GatewayAvdClientID = 2013,
+	FreeRDP_GatewayAzureActiveDirectory = 2014,
 	FreeRDP_ProxyHostname = 2016,
 	FreeRDP_ProxyUsername = 2018,
 	FreeRDP_ProxyPassword = 2019,
+	FreeRDP_GatewayAvdScope = 2021,
+	FreeRDP_GatewayAvdAccessTokenFormat = 2022,
+	FreeRDP_GatewayAvdAccessAadFormat = 2023,
+	FreeRDP_GatewayHttpReferer = 2024,
+	FreeRDP_GatewayHttpUserAgent = 2025,
+	FreeRDP_GatewayHttpMsUserAgent = 2026,
 	FreeRDP_RemoteApplicationName = 2113,
 	FreeRDP_RemoteApplicationIcon = 2114,
 	FreeRDP_RemoteApplicationProgram = 2115,
@@ -574,7 +585,7 @@ typedef enum
 } FreeRDP_Settings_Keys_Pointer;
 
 
-/** Highest indes in the rdpSettings stable API
+/** Highest index in the rdpSettings stable API
  *
  *  \since version 3.0.0
  */
